rgbmatch
========

Usage
-----

```python
from rgbmatch import closest_rgb

rgbmatch.closest_rgb(
    (0,0,0),
    [
        (95,110,5),
        (4,4,4),
        (100,100,100)
    ]
)

# (4, 4, 4)
```

Call ``help(closest_rgb)`` for more information.


Links
-----

- [Repository](https://github.com/phoenixr-codes/rgbmatch/)
- [PyPI](https://pypi.org/project/rgbmatch)
